@@ -21,7 +21,7 @@ from twisted.python.util import FancyEqMixin
 from twisted.python.reflect import (
     prefixedMethods, accumulateMethods, fullyQualifiedName)
 from twisted.python.deprecate import deprecated
-from twisted.python.versions import Version, getVersionString
+from incremental import Version, getVersionString
 from twisted.python.failure import Failure
 from twisted.trial import unittest
 from twisted.internet.defer import Deferred, fail, succeed
@@ -98,7 +98,7 @@ class TestFailureTests(pyunit.TestCase):
         """
         result = pyunit.TestResult()
         self.suite.run(result)
-        self.failIf(result.wasSuccessful())
+        self.assertFalse(result.wasSuccessful())
         self.assertEqual(result.errors, [])
         self.assertEqual(len(result.failures), 1)
         self.assertEqual(result.failures[0][0], self.test)
@@ -334,7 +334,7 @@ class SynchronousAssertionsTests(unittest.SynchronousTestCase):
 
     def test_assertEqualNoneMessage(self):
         """
-        If a message is specified as C{None}, it is not included in the error
+        If a message is specified as L{None}, it is not included in the error
         message of L{assertEqual}.
         """
         exceptionForNone = self.assertRaises(
@@ -367,7 +367,7 @@ class SynchronousAssertionsTests(unittest.SynchronousTestCase):
 
     def test_failUnlessRaises_expected(self):
         x = self.failUnlessRaises(ValueError, self._raiseError, ValueError)
-        self.failUnless(isinstance(x, ValueError),
+        self.assertTrue(isinstance(x, ValueError),
                         "Expect failUnlessRaises to return instance of raised "
                         "exception.")
 
@@ -398,7 +398,7 @@ class SynchronousAssertionsTests(unittest.SynchronousTestCase):
     def test_failUnlessRaises_failureException(self):
         x = self.failUnlessRaises(self.failureException, self._raiseError,
                                   self.failureException)
-        self.failUnless(isinstance(x, self.failureException),
+        self.assertTrue(isinstance(x, self.failureException),
                         "Expected %r instance to be returned"
                         % (self.failureException,))
         try:
@@ -896,7 +896,7 @@ class WarningAssertionTests(unittest.SynchronousTestCase):
 
     def test_assertWarnsFilter(self):
         """
-        Test assertWarns on a warning filterd by default.
+        Test assertWarns on a warning filtered by default.
         """
         def deprecated(a):
             warnings.warn("Woo deprecated", category=PendingDeprecationWarning)
@@ -1200,11 +1200,11 @@ class AssertionNamesTests(unittest.SynchronousTestCase):
             if not callable(value):
                 continue
             if name.endswith('Equal'):
-                self.failUnless(hasattr(self, name+'s'),
+                self.assertTrue(hasattr(self, name+'s'),
                                 "%s but no %ss" % (name, name))
                 self.assertEqual(value, getattr(self, name+'s'))
             if name.endswith('Equals'):
-                self.failUnless(hasattr(self, name[:-1]),
+                self.assertTrue(hasattr(self, name[:-1]),
                                 "%s but no %s" % (name, name[:-1]))
                 self.assertEqual(value, getattr(self, name[:-1]))
 
@@ -1283,7 +1283,8 @@ class CallDeprecatedTests(unittest.SynchronousTestCase):
         # by callDeprecated.  Flush it now to make sure it did happen and to
         # prevent it from showing up on stdout.
         warningsShown = self.flushWarnings()
-        self.assertEqual(len(warningsShown), 1)
+        self.assertEqual(len(warningsShown), 1,
+            "Unexpected warnings: {}".format(warningsShown))
 
 
     def test_callDeprecationWithMessage(self):
